@@ -5,10 +5,11 @@
 """
 Example script for running a measurement using i2c senors only.
 """
-from pyserialsensors.devices.FTDI import init_all
-from pyserialsensors.tools.bulk import setup, ThreadWithReturnValue
-from pyserialsensors.core.i2controller import MmsI2cController
-from pyserialsensors.core.i2controller import MmsSpiController
+
+from ..devices.FTDI import init_all
+from ..tools.bulk import setup, ThreadWithReturnValue
+from ..core.i2controller import MmsI2cController
+from ..core.i2controller import MmsSpiController
 
 import logging
 
