@@ -8,18 +8,18 @@ different types of device interfaces can be used
 """
 
 from threading import Thread
-from .core.i2controller import MmsI2cController
-from .core.i2controller import MmsSpiController
-from .core.toolbox import scan_i2c
-from .core.toolbox import scan_spi
+from ..core.i2controller import MmsI2cController
+from ..core.i2controller import MmsSpiController
+from ..core.toolbox import scan_i2c
+from ..core.toolbox import scan_spi
 
 
 class ThreadWithReturnValue(Thread):
     """
     Heper class for device threading
     """
-    def __init__(self, group=None, target=None, name=None,
-                 args=(), kwargs={}):
+
+    def __init__(self, group=None, target=None, name=None, args=(), kwargs={}):
         """
         Setup threading model
         See threading.Thread: https://docs.python.org/3/library/threading.html
@@ -47,8 +47,10 @@ def setup(device, **kwargs):
     if isinstance(device, MmsSpiController):
         device = [device]
     elif not isinstance(device, list):
-        raise TypeError(f"Incorrect type {type(device)} for \
-                device [only list/I2Ccontroller/SPIcontroller]")
+        raise TypeError(
+            f"Incorrect type {type(device)} for \
+                device [only list/I2Ccontroller/SPIcontroller]"
+        )
 
     # Check initializations status
     for dev in device:
@@ -61,7 +63,9 @@ def setup(device, **kwargs):
             elif isinstance(dev, MmsSpiController):
                 dev = scan_spi(dev, **kwargs)
             else:
-                raise TypeError(f"Incorrect type {type(dev)} during \
-                        scan [only list/I2Ccontroller/SPIcontroller]")
+                raise TypeError(
+                    f"Incorrect type {type(dev)} during \
+                        scan [only list/I2Ccontroller/SPIcontroller]"
+                )
 
     return device
